@@ -1,8 +1,7 @@
 from django.contrib import admin
 
-from nomadblog.models import Post, Blog, Category, BlogUser
+from nomadblog.models import Blog, Category, BlogUser
 
 admin.site.register(Blog)
 admin.site.register(Category)
-admin.site.register(Post)
 admin.site.register(BlogUser)
