@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 
 urlpatterns = patterns('nomadblog.views',
@@ -16,7 +16,7 @@ urlpatterns = patterns('nomadblog.views',
     ),
     # List categories
     url(
-        regex=r'^categories/$',
+        regex=r'^categories/list/all/$',
         view='list_categories',
         name='list_categories',
     ),
